/*
 * Lynx - Hypertext navigation system
 *
 *   (c) Copyright 1992, 1993, 1994 University of Kansas
 *	 1996: GNU General Public License
 */

/*******************************************************************
 * There are three sections to this document
 *  Section 1.  Things you MUST change or verify
 *	Section 1a)  VMS specific things
 *	Section 1b)  UNIX specific things
 *	Section 1c)  ALL Platforms
 *
 *  Section 2.  Things you should probably check!
 *
 *  Section 3.  Things you should only change after you have a good
 *              understanding of the program!
 *
 */

#ifndef USERDEFS_H
#define USERDEFS_H

/*******************************************************************
 * Things you must change
 *  Section 1. 
 */

/*******************************************************************
 * Things you must change  VMS specific
 *  Section 1a). 
 */
#ifdef VMS
/**************************
 * TEMP_SPACE is where Lynx temporary cache files will be placed.
 * Temporary files are removed automatically as long as nothing
 * goes terribly wrong :)
 * This definition can be overridden at run time by defining a
 * "LYNX_TEMP_SPACE" VMS logical.
 */
#define TEMP_SPACE "sys$scratch:"

/**************************
 * LYNX_CFG_FILE is the location and name of the default lynx
 * global configuration file.  It is sought and processed at
 * startup of Lynx, followed by a seek and processing of a
 * personal RC file (.lynxrc in the user's HOME directory,
 * created if the user saves values in the 'o'ptions menu).
 * You also can define the location and name of the global
 * configuration file via a VMS logical, "LYNX_CFG", which
 * will override the "LYNX_CFG_FILE" definition here.  SYS$LOGIN:
 * can be used as the device in either or both definitions if
 * you want lynx.cfg treated as a personal configuration file.
 * You also can use Unix syntax with a '~' for a subdirectory
 * of the login directory, (e.g., ~/lynx/lynx.cfg).
 * The -cfg command line switch will override these definitions.
 * You can pass the compilation default via build.com or descrip.mms.
 *
 * Note that any SUFFIX or VIEWER mappings in the configuration
 * files will be overidden by any suffix or viewer mappings
 * that are established as defaults in src/HTInit.c.
 */
#ifndef LYNX_CFG_FILE
#define LYNX_CFG_FILE "Lynx_Dir:lynx.cfg"
#endif /* LYNX_CFG_FILE */

/**************************
 * The EXTENSION_MAP file allows you to map file suffix's to 
 * mime types.
 * These global and personal files override anything in
 * lynx.cfg or src/HTInit.c
 */
#define GLOBAL_EXTENSION_MAP "Lynx_Dir:mime.types"
#define PERSONAL_EXTENSION_MAP "mime.types"

/**************************
 * The MAILCAP file allows you to map file MIME types to 
 * external viewers.
 * These global and personal files override anything in
 * lynx.cfg or src/HTInit.c
 */ 
#define GLOBAL_MAILCAP "Lynx_Dir:mailcap"
#define PERSONAL_MAILCAP ".mailcap"

/**************************
 * This define will be used for a default in src/HTInit.c.
 * Make it the full path and name of the xloadimage command.
 * Put 'echo' or something like it here if you don't have it.
 * It can be anything that will handle GIF, TIFF and other
 * popular image formats (xv does).
 * You must also have a "%s" for the filename
 */
#define XLOADIMAGE_COMMAND "xv %s"

/**************************
 * The full path and name of the standard VMS "mail" command.
 *
 * The mail command will be spawned as a subprocess of lynx
 * and used to send replies and error messages.  It must be
 * defined here, and can be changed in lynx.cfg.
 * SYSTEM_MAIL must be able to accept a subject line through
 * the use of the /subject="SUBJECT" option.
 * If your mailer uses another syntax, some hacking of the
 * mailmsg() and reply_by_mail() functions in LYMail.c may
 * be required.
 */
#define SYSTEM_MAIL "mail"

/*************************
 * below is the argument for an sprintf command that will add
 * "IN%""ADDRESS""" to the Internet mail address given by the user.
 * It is structured for PMDF's IN%"INTERNET_ADDRESS" scheme.  The %s
 * is replaced with the address given by the user.  If you are using
 * a different Internet mail transport, change the IN appropriately
 * (e.g., to SMTP, MX, or WINS), here or in lynx.cfg.
 */
#define MAIL_ADRS "\"IN%%\"\"%s\"\"\""

/*************************
 * The foreign command for the ANU-NEWS client (presumably "NEWS").
 * which serves as a transparent vector for posting to newsgroups
 * from Lynx via the ANU-NEWS client's server.  The account running
 * Lynx must have access to the ANU-NEWS client, which in turn must
 * have posting privileges (the news server could also be ANU-NEWS,
 * or any other server to which the ANU-NEWS client has access).
 *
 * The ANU-NEWS software for VMS is available from ftp.cc.ukans.edu.
 *
 * Define INEWS as "none" if you do not have access to an ANU-NEWS
 * client with a server for posting to newsgroups from Lynx.
 */
#define INEWS "NEWS"

/*********************************
 * If USE_FIXED_RECORDS is set to TRUE here and/or in lynx.cfg, Lynx will
 * convert 'd'ownloaded binary files to FIXED 512 record format before saving
 * them to disk or acting on a DOWNLOADER option.  If set to FALSE, the
 * headers of such files will indicate that they are Stream_LF with Implied
 * Carriage Control, which is incorrect, and can cause downloading software
 * to get confused and unhappy.  If you do set it FALSE, you can use the
 * FIXED512.COM command file, which is included in this distribution, to do
 * the conversion externally.
 */
#define USE_FIXED_RECORDS	TRUE	/* convert binaries to FIXED 512 */

/********************************
 * If NO_ANONYMOUS_EMAIL is defined, Lynx will not offer to insert X-From
 * and X_Personal_Name lines in the body of email messages.  On VMS, the
 * actual From and Personal Name (if defined for the account) headers always
 * are those of the account running the Lynx image.  If the account is not
 * the one to which the recipient should reply, you can indicate the alternate
 * address and personal name via the X-From and X_Personal_Name entries, but
 * the recipient must explicitly send the reply to the X_From address, rather
 * than using the VMS REPLY command (which will use the actual From address).
 *
 * This symbol constant might be defined on Unix for security reasons that
 * don't apply on VMS.  There is no security reason for defining this on VMS,
 * but if you have no anonymous accounts (i.e., the From always will point to
 * the actual user's email address, you can define it to avoid the bother of
 * X-From and X_Personal_Name offers.
 */
/*#define NO_ANONYMOUS_EMAIL TRUE */

/*******************************************************************
 * Things you must change  UNIX specific
 *  Section 1b). 
 */
#else     /* UNIX */

/**************************
 * LYNX_CFG_FILE is the location and name of the default lynx
 * global configuration file.  It is sought and processed at
 * startup of Lynx, followed by a seek and processing of a
 * personal RC file (.lynxrc in the user's HOME directory,
 * created if the user saves values in the 'o'ptions menu).
 * You also can define the location and name of the global
 * configuration file via an environment variable, "LYNX_CFG",
 * which will override the "LYNX_CFG_FILE" definition here.
 * You can use '~' in either or both definitions if you want
 * lynx.cfg treated as a personal configuration file.  The
 * -cfg command line switch will override these definitions.
 * You can pass the compilation default via the Makefile.
 *
 * Note that any SUFFIX or VIEWER mappings in the configuration
 * files will be overidden by any suffix or viewer mappings
 * that are established as defaults in src/HTInit.c.
 */
#ifndef LYNX_CFG_FILE
#define LYNX_CFG_FILE "/local/lib/lynx/lynx.cfg"
#endif /* LYNX_CFG_FILE */

/**************************
 * The EXTENSION_MAP file allows you to map file suffix's to 
 * mime types.
 * These global and personal files override anything in
 * lynx.cfg or src/HTInit.c
 */
#define GLOBAL_EXTENSION_MAP "/local/lib/lynx/mime.types"
#define PERSONAL_EXTENSION_MAP ".mime.types"

/**************************
 * The MAILCAP file allows you to map file MIME types to 
 * external viewers.
 * These global and personal files override anything in
 * lynx.cfg or src/HTInit.c
 */
#define GLOBAL_MAILCAP "/local/lib/lynx/mailcap"
#define PERSONAL_MAILCAP ".mailcap"

/**************************
 * the full path and name of the telnet command
 */
#define TELNET_COMMAND "telnet"

/**************************
 * the full path and name of the tn3270 command
 */
#define TN3270_COMMAND "tn3270"

/**************************
 * the full path and name of the rlogin command
 */
#define RLOGIN_COMMAND "rlogin"

/*************************
 * This define will be used for a default in src/HTInit.c.
 * Make it the full path and name of the xloadimage command.
 * Put 'echo' or something like it here if you don't have it.
 * It can be anything that will handle GIF, TIFF and other
 * popular image formats (xv does).
 * You must also have a "%s" for the filename; "&" for
 * background is optional
 */
#define XLOADIMAGE_COMMAND "xv %s &"

/*************************
 * The full path and name of the inews program
 *
 * A "mini" inews has been included in the utils directory.
 *
 * set empty or to "none" if you don't have or want it.
 */
#define INEWS "inews"

/**************************
 * For UNIX systems this should be sendmail
 * sendmail should be in /usr/lib 
 *
 * You definitely want sendmail, not mail or elm or something else,
 * except in the case where MMDF is your mail agent.
 * For MMDF you should use submit (SCO)
 *
 * SYSTEM_MAIL must be defined here.  You can change it in lynx.cfg.
 *
 * If you do not use the recommended mailers, some hacking of
 * the mailmsg() and reply_by_mail() functions in LYMail.c, or
 * interposition of a script, may be required.
 */
#ifdef MMDF
#define SYSTEM_MAIL "/usr/mmdf/bin/submit" 
#else
#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__bsdi__)
#define SYSTEM_MAIL "/usr/sbin/sendmail"
#else /* everthing else: */
#define SYSTEM_MAIL "/usr/lib/sendmail" 
#endif /* __FreeBSD || __NetBSD__ || __bsdi__ */
#endif /* MMDF */

/**************************
 * A place to put temporary files, it's almost always "/tmp/" on
 * UNIX systems
 * This definition can be overridden at run time by setting a
 * "LYNX_TEMP_SPACE" environment symbol.
 */
#define TEMP_SPACE "/tmp/"

/********************************
 * Don't let the user enter his/hers email address when sending a message.
 * Anonymous mail makes it far too easy for a user to spoof someone elses
 * email address.
 * This requires that your mailer agent put in the From: field for you.

 * The default should be to uncomment this line but there probably are too
 * many mail agents out there that won't do the right thing if there is no
 * From: line.
 */
/* #define NO_ANONYMOUS_EMAIL TRUE */

/********************************
 * LIST_FORMAT defines the display for local files when LONG_LIST
 * is defined in the Makefile.  The default set here can be changed
 * in lynx.cfg.
 *
 * The percent items in the list are interpreted as follows:
 *
 *	%p	Unix-style permission bits
 *	%l	link count
 *	%o	owner of file
 *	%g	group of file
 *	%d	date of last modification
 *	%a	anchor pointing to file or directory
 *	%A	as above but don't show symbolic links
 *	%k	size of file in Kilobytes
 *	%K	as above but omit size for directories
 *	%s	size of file in bytes
 *
 * Anything between the percent and the letter is passed on to sprintf.
 * A double percent yields a literal percent on output.  Other characters
 * are passed through literally.
 *
 * If you want only the filename:  "    %a"
 *
 * If you want a brief output:     "    %4K %-12.12d %a"
 *
 * For the Unix "ls -l" format:    "    %p %4l %-8.8o %-8.8g %7s %-12.12d %a"
 */
#define LIST_FORMAT "    %p %4l %-8.8o %-8.8g %7s %-12.12d %a"

#endif /* VMS OR UNIX */

/*************************************************************
 *  Section 1c)   Every platform must change or verify these
 *
 */

/*****************************
 * STARTFILE is the default file if none is specified on the command line
 * or via a WWW_HOME environment variable.
 * 
 * note: STARTFILE must be a URL.  See the Lynx online help for more
 *       information on URL's
 */
#define STARTFILE "http://www.nyu.edu/pages/wsn/subir/lynx.html"

/*****************************
 * HELPFILE must be defined as a URL and must have a 
 * complete path if local:
 * file://localhost/PATH_TO/lynx_help/lynx_help_main.html
 *   Replace PATH_TO with the path to the lynx_help subdirectory
 *   for this distribution (use SHELL syntax including the device
 *   on VMS systems).
 * The default HELPFILE is:
 * http://www.nyu.edu/pages/wsn/subir/lynx.html
 *   This should be changed here or in lynx.cfg to the local path.
 */
#define HELPFILE "/local/lib/lynx/lynx_help/lynx_help_main.html"
/* #define HELPFILE "file://localhost/PATH_TO/lynx_help/lynx_help_main.html" */

/*****************************
 * DEFAULT_INDEX_FILE is the default file retrieved when the
 * user presses the 'I' key when viewing any document.
 * An index to your CWIS can be placed here or a document containing
 * pointers to lots of interesting places on the web.
 */
#define DEFAULT_INDEX_FILE "http://www.ncsa.uiuc.edu/SDG/Software/Mosaic/MetaIndex.html"

/*******************************
 * If GOTOBUFFER is set to TRUE here or in lynx.cfg the last entered
 * goto URL, if any, will be offered as a default for reuse or editing
 * when the 'g'oto command is entered.  All previously used goto URLs
 * can be accessed for reuse or editing via a circular buffer invoked
 * with the Up-Arrow or Down-Arrow keys after entering the 'g'oto
 * command, whether or not a default is offered.
 */
#define GOTOBUFFER	  FALSE

/*****************************
 * JUMPFILE is the default local file checked for shortcut URL's when
 * the user presses the 'J' (JUMP) key.  The user will be prompted for
 * a shortcut entry (analogously to 'g'oto), and can enter one
 * or use '?' for a list of the shortcuts with associated links to
 * their actual URL's.  See the sample jumps files in the samples
 * subdirectory.  Make sure your jumps file includes a '?' shortcut
 * for a file://localhost URL to itself:
 *
 * <dt>?<dd><a href="file://localhost/path/jumps.html">This Shortcut List</a>
 *
 * If not defined here or in lynx.cfg, the JUMP command will invoke
 * the NO_JUMPFILE statusline message.  The prompt associated with the
 * default jumps file is defined as JUMP_PROMPT, below, and can be modified
 * in lynx.cfg.  Additional, alternate jumps files can be defined and
 * mapped to keystrokes, and alternate prompts can be set for them, in
 * lynx.cfg, but at least one default jumps file and associated prompt
 * should be established before adding others.
 *
 * On VMS, use Unix SHELL syntax (including a lead slash) to define it.
 *
 * Do not include "file://localhost" in the definition.
 */
/* #define JUMPFILE "/Lynx_Dir/jumps.html" */

/*******************************
 * The "not available" statusline message, and default prompt,
 * for Jumps.  The default prompt can be changed in lynx.cfg.
 */
#define NO_JUMPFILE "No jump file is currently available."
#define JUMP_PROMPT "Jump to (use '?' for list): "

/*******************************
 * If JUMPBUFFER is set to TRUE here or in lynx.cfg the last entered
 * jump shortcut, if any, will be offered as a default for reuse or
 * editing when the JUMP command is entered.  All previously used
 * shortcuts can be accessed for reuse or editing via a circular buffer
 * invoked with the Up-Arrow or Down-Arrow keys after entering the JUMP
 * command, whether or not a default is offered.  If you have multiple
 * jumps files and corresponding key mappings, each will have its own
 * circular buffer.
 */
#define JUMPBUFFER	  FALSE

/********************************
 * If PERMIT_GOTO_FROM_JUMP is defined, then a : or / in a jump target
 * will be treated as a full or partial URL (to be resolved versus the
 * startfile), and will be handled analogously to a 'g'oto command.
 * Such "random URLs" will be entered in the circular buffer for goto
 * URLs, not the buffer for jump targets (shortcuts).  If the target
 * is the single character ':', it will be treated equivalently to an
 * Up-Arrow or Down-Arrow following a 'g'oto command, for accessing the
 * circular buffer of goto URLs.
 */
/* #define PERMIT_GOTO_FROM_JUMP */

/*****************************
 * If LYNX_HOST_NAME is defined here and/or in lynx.cfg, it will be
 * treated as an alias for the local host name in checks for URLs on
 * the local host (e.g., when the -localhost switch is set), and this
 * host name, "localhost", and HTHostName (the fully qualified domain
 * name of the system on which Lynx is running) will all be passed as
 * local.  A different definition in lynx.cfg will override this one.
 */
/* #define LYNX_HOST_NAME "www.cc.ukans.edu" */

/*********************
 * LOCAL_DOMAIN is used to determine if a user is local
 * to your campus or organization.  CHANGE THIS here or
 * in lynx.cfg.
 */
#define LOCAL_DOMAIN "ukans.edu"

/********************************
* The DEFAULT_CACHE_SIZE specifies the number of WWW documents to be
* cached in memory at one time.
*
* This so-called cache size (actually, number) may be modified in lynx.cfg
* and or with the command line argument -cache=NUMBER  The minimum allowed
* value is 2, for the current document and at least one to fetch, and there
* is no absolute maximum number of cached documents.  On Unix, and VMS not
* compiled with VAXC, whenever the number is exceeded the least recently
* displayed document will be removed from memory.
*
* On VMS compiled with VAXC, the DEFAULT_VIRTUAL_MEMORY_SIZE specifies the
* amount (bytes) of virtual memory that can be allocated and not yet be freed
* before previous documents are removed from memory.  If the values for both
* the DEFAULT_CACHE_SIZE and DEFAULT_VIRTUAL_MEMORY_SIZE are exceeded, then
* least recently displayed documents will be freed until one or the other
* value is no longer exceeded.  The value can be modified in lynx.cfg.
*
* The Unix and VMS but not VAXC implementations use the C library malloc's
* and calloc's for memory allocation, and procedures for taking the actual
* amount of cache into account still need to be developed.  They use only
* the DEFAULT_CACHE_SIZE value, and that specifies the absolute maximum
* number of documents to cache (rather than the maximum number only if
* DEFAULT_VIRTUAL_MEMORY_SIZE has been exceeded, as with VAXC/VAX).
*/
#define DEFAULT_CACHE_SIZE 10

#if defined(VMS) && defined(VAXC) && !defined(__DECC)
#define DEFAULT_VIRTUAL_MEMORY_SIZE 512000
#endif /* VMS && VAXC && !__DECC */

/********************************
 * If ALWAYS_RESUBMIT_FORMS is set TRUE, Lynx always will submit
 * forms, dumping any cache from a previous submission of the form
 * with the same content.  If FALSE, the user retains the option to
 * resubmit via the RESUBMIT command, and is informed of the option
 * via the statusline when positioned on a form submit button.
 *
 * The default defined here can be changed in lynx.cfg, and can be
 * toggled via the -resubmit_forms command line switch.
 */
#define ALWAYS_RESUBMIT_FORMS FALSE

/********************************
 * CHARACTER_SET defines the default character set, i.e., that assumed
 * to be installed on the user's termimal.  It determines which characters
 * or strings will be used to represent 8-bit character entities within
 * HTML.  New character sets may be defined by modifying the file
 * src/LYCharSets.c in the Lynx source code distribution and recompiling.
 * For Asian (CJK) character sets, it also determines how Kanji code will
 * be handled.  The default defined here can be changed in lynx.cfg, and
 * via the 'o'ptions menu.  The 'o'ptions menu setting will be stored in
 * the user's RC file whenever those settings are saved, and thereafter
 * will be used as the default.  Also see lynx.cfg for information about
 * the -raw switch and LYE_RAW_TOGGLE command.
 * The default character sets include:
 *    ISO Latin 1
 *    ISO Latin 2
 *    Other ISO Latin
 *    DEC Multinational
 *    IBM PC character set
 *    IBM PC codepage 850
 *    Macintosh (8 bit)
 *    NeXT character set
 *    KOI8-R character set
 *    Chinese
 *    Japanese (EUC)
 *    Japanese (SJIS)
 *    Korean
 *    Taipei (Big5)
 *    7 bit approximations
 */
#define CHARACTER_SET "ISO Latin 1"

/*****************************
 * PREFERRED_LANGUAGE is the language in MIME notation (e.g., "en",
 * "fr") which will be indicated by Lynx in its Accept-Language headers
 * as the preferred language.  If available, the document will be
 * transmitted in that language.  This definition can be overriden via
 * lynx.cfg.  Users also can change it via the 'o'ptions menu and save
 * that preference in their RC file. This may be a comma-separated list
 * of languages in decreasing preference.
 */
#define PREFERRED_LANGUAGE "en"

/*****************************
 * PREFERRED_CHARSET specifies the character set in MIME notation (e.g.,
 * "ISO-8859-2", "ISO-8859-5") which Lynx will indicate you prefer in
 * requests to http servers using an Accept-Charsets header.  The value
 * should NOT include "ISO-8859-1" or "US-ASCII", since those values are
 * always assumed by default.  If a file in that character set is available,
 * the server will send it.  Otherwise, the server will send the file in
 * ISO-8859-1 or US-ASCII.  Users can change or eliminate this definition
 * via the 'o'ptions menu and save that preference in their RC file.
 */
#define PREFERRED_CHARSET ""

/********************************
 * URL_DOMAIN_PREFIXES and URL_DOMAIN_SUFFIXES are strings which will be
 * prepended (together with a scheme://) and appended to the first element
 * of command line or 'g'oto arguments which are not complete URLs and
 * cannot be opened as a local file (file://localhost/string).  Both
 * can be comma-separated lists.  Each prefix must end with a dot, each
 * suffix must begin with a dot, and either may contain other dots (e.g.,
 * .com.jp).  The default lists are defined here, and can be changed
 * in lynx.cfg.  Each prefix will be used with each suffix, in order,
 * until a valid Internet host is created, based on a successful DNS
 * lookup (e.g., foo will be tested as www.foo.com and then www.foo.edu
 * etc.).  The first element can include a :port and/or /path which will
 * be restored with the expanded host (e.g., wfbr:8002/dir/lynx will
 * become http://www.wfbr.edu:8002/dir/lynx).  The prefixes will not be
 * used if the first element ends in a dot (or has a dot before the
 * :port or /path), and similarly the suffixes will not be used if the
 * the first element begins with a dot (e.g., .nyu.edu will become
 * http://www.nyu.edu without testing www.nyu.com).  Lynx will try to
 * guess the scheme based on the first field of the expanded host name,
 * and use "http://" as the default (e.g., gopher.wfbr.edu or gopher.wfbr.
 * will be made gopher://gopher.wfbr.edu).
 */
#define URL_DOMAIN_PREFIXES "www."
#define URL_DOMAIN_SUFFIXES ".com,.edu,.net,.org"

/********************************
 * If LIST_NEWS_NUMBERS is set TRUE, Lynx will use an ordered list
 * and include the numbers of articles in news listings, instead of
 * using an unordered list.
 *
 * The default defined here can be changed in lynx.cfg.
 */
#define LIST_NEWS_NUMBERS FALSE

/********************************
 * If LIST_NEWS_DATES is set TRUE, Lynx will include the dates of
 * articles in news listings.  The dates always are included in the
 * articles, themselves.
 *
 * The default defined here can be changed in lynx.cfg.
 */
#define LIST_NEWS_DATES FALSE


/****************************************************************
 *   Section 2.   Things that you probably want to change or review
 *
 */

/*****************************
 * The following three definitions set the number of seconds for
 * pauses following statusline messages that would otherwise be
 * replaced immediately, and are more important than the unpaused
 * progress messages.  Those set by INFOSECS are also basically
 * progress messages (e.g., that a prompted input has been cancelled)
 * and should have the shortest pause.  Those set by MESSAGESECS are
 * informational (e.g., that a function is disabled) and should have
 * a pause of intermediate duration.  Those set by ALERTSECS typically
 * report a serious problem and should be paused long enough to read
 * whenever they appear (typically unexpectedly).  The default values
 * defined here can be modified via lynx.cfg, should longer pauses be
 * desired for braille-based access to Lynx.
 */
#define INFOSECS 1
#define MESSAGESECS 2
#define ALERTSECS 3

/*****************************
 * Enter the name of your anonymous account if you have one
 * as ANONYMOUS_USER.  UNIX systems will use a cuserid
 * or get_login call to determine if the current user is
 * the ANONYMOUS_USER.
 *
 * VMS systems cannot use this feature, so they must specify
 * anonymous accounts using the "-anonymous" command line option.
 *
 * Other systems may use the "-anonymous" option for multiple
 * accounts or precautionary reasons as well.
 *
 * It is very important to have this correctly defined if you 
 * have an anonymous account.  If you do not you will be putting 
 * yourself at GREAT security risk!
 *
 * Later on in this file you can specify privileges for the
 * anonymous account.
 */
#define ANONYMOUS_USER "" 

/******************************
 * SHOW_CURSOR controls whether or not the cursor is hidden
 * or appears over the link.  This is just the default, it
 * can be turned on with the -show_cursor command line option.
 * Showing the cursor is handy if you have really stupid terminals
 * that can't do bold and reverse video at the same time or at all.
 */
#define SHOW_CURSOR FALSE

/******************************
 * BOXVERT and BOXHORI control the layout of popup menus.  Set to 0 if your
 * curses supports line-drawing characters, set to '*' or any other character
 * to not use line-drawing (e.g., '|' for vertical and '-' for horizontal).
 */
#define BOXVERT '*'
/* #define BOXVERT 0 */
#define BOXHORI '*'
/* #define BOXHORI 0 */

/******************************
 * LY_UMLAUT controls the 7-bit expansion of characters with dieresis or
 * umlaut.  If defined, a digraph is displayed, e.g., auml --> ae
 * Otherwise, a single character is displayed,  e.g., auml --> a
 */
#define LY_UMLAUT

/*******************************
 * set to FALSE if you don't want users of your anonymous account
 * who are calling from inside your local domain
 * to be able to telnet back out
 */
#define CAN_ANONYMOUS_INSIDE_DOMAIN_TELNET	TRUE

/*******************************
 * set to FALSE if you don't want users of your anonymous
 * account who are calling from outside your
 * local domain to be able to telnet back out
 */
#define CAN_ANONYMOUS_OUTSIDE_DOMAIN_TELNET	TRUE

/*******************************
 * set to FALSE if you don't want users of your anonymous account
 * who are calling from inside your local domain
 * to be able to read news
 */
#define CAN_ANONYMOUS_INSIDE_DOMAIN_READ_NEWS	TRUE

/*******************************
 * set to FALSE if you don't want users of your anonymous
 * account who are calling from outside your
 * local domain to be able to read news
 */
#define CAN_ANONYMOUS_OUTSIDE_DOMAIN_READ_NEWS	FALSE

/*******************************
 * set to FALSE if you don't want users of your anonymous
 * account who are calling from inside your local domain
 * to be able to use ftp
 */
#define CAN_ANONYMOUS_INSIDE_DOMAIN_FTP		TRUE

/*******************************
 * set to FALSE if you don't want users of your anonymous
 * account who are calling from outside your local domain
 * to be able to use ftp
 */
#define CAN_ANONYMOUS_OUTSIDE_DOMAIN_FTP	TRUE

/*******************************
 * set to FALSE if you don't want users of your anonymous
 * account who are calling from inside your local domain 
 * to be able to use rlogin
 */
#define CAN_ANONYMOUS_INSIDE_DOMAIN_RLOGIN	TRUE

/*******************************
 * set to FALSE if you don't want users of your anonymous
 * account who are calling from outside your local domain
 * to be able to use rlogin
 */
#define CAN_ANONYMOUS_OUTSIDE_DOMAIN_RLOGIN	TRUE

/*******************************
 * set to FALSE if you don't want users of your anonymous
 * account to be able to goto random URL's. (The 'g' command)
 */
#define CAN_ANONYMOUS_GOTO		TRUE

/*******************************
 * set to FALSE if you don't want users of your anonymous
 * account to be able to specify a port in 'g'oto commands
 * for telnet URL's.
 */
#define CAN_ANONYMOUS_GOTO_TELNET_PORT	FALSE

/*******************************
 * set to FALSE if you don't want users of your anonymous
 * account to be able to jump to URL's (The 'J' command)
 * via the shortcut entries in your JUMPFILE.
 */
#define CAN_ANONYMOUS_JUMP	TRUE

/*******************************
 * set to FALSE if you don't want users of your anonymous
 * account to be able to mail
 */
#define CAN_ANONYMOUS_MAIL	TRUE

/*******************************
 * set to FALSE if you don't want users of your anonymous
 * account to be able to print
 */
#define CAN_ANONYMOUS_PRINT	FALSE

/*******************************
 * Execution links/scripts configuration.
 *
 * Execution links and scripts allow you to run
 * local programs by activating links within Lynx.
 *
 * An execution link is of the form:
 *
 *     lynxexec:<COMMAND>
 * or:
 *     lynxexec://<COMMAND>
 * or:
 *     lynxprog:<COMMAND>
 * or:
 *     lynxprog://<COMMAND>
 *
 * where <COMMAND> is a command that Lynx will run when the link is
 * activated.  The double-slash should be included if the command begins
 * with an '@', as for executing VMS command files.  Otherwise, the double-
 * slash can be omitted.
 * Use lynxexec for commands or scripts that generate a screen output which
 * should be held via a prompt to press <return> before returning to Lynx
 * for display of the current document.
 * Use lynxprog for programs such as mail which do require a pause before
 * Lynx restores the display of the current document.
 *
 * Execution scripts take the form of a standard
 * URL.  Extension mapping or MIME typing is used
 * to decide if the file is a script and should be
 * executed.  The current extensions are:
 * .csh, .ksh, and .sh on UNIX systems and .com on
 * VMS systems.  Any time a file of this type is
 * accessed Lynx will look at the user's options
 * settings to decide if the script can be executed.
 * Current options include: Only exec files that
 * reside on the local machine and are referenced
 * with a "file://localhost" URL, All execution
 * off, and all execution on.
 *
 * The following definitions will add execution
 * capabilities to Lynx.  You may define none, one
 * or both.
 *
 * I strongly recommend that you define neither one
 * of these since execution links/scripts can represent
 * very serious security risk to your system and its
 * users.  If you do define these I suggest that
 * you only allow users to execute files/scripts
 * that reside on your local machine. 
 *
 * YOU HAVE BEEN WARNED!
 *
 * Note: if you are enabling execution scripts you should
 * also see src/HTInit.c to verify/change the execution
 * script extensions and/or commands.
 */
/* #define EXEC_LINKS  */ 
/* #define EXEC_SCRIPTS  */ 

/**********
 * UNIX:
 * =====
 * CGI script support. Defining LYNXCGI_LINKS allows you to use the 
 *
 *   lynxcgi:path
 *
 * URL which allows lynx to access a cgi script directly without the need for
 * a http daemon. Redirection or mime support is not supported but just about
 * everything else is. If the path is not an executable file then the URL is
 * rewritten as file://localhost and passed to the file loader. This means that
 * if your http:html files are currently set up to use relative addressing, you
 * should be able to fire up your main page with lynxcgi:path and everything
 * should work as if you were talking to the http daemon.
 *
 * Note that you must use a LYNXCGI_PATH directive in your lynx.cfg file as
 * well in order for this to work.
 *
 * The cgi scripts are called with a fork()/execve() sequence so you don't
 * have to worry about people trying to abuse the code. :-)
 *
 *     George Lindholm (George.Lindholm@ubc.ca)
 *
 * VMS:
 * ====
 * Uncomment the following line to define LYNXCGI_LINK, and when
 * running Lynx, enter  lynxcgi:advice  as a G)oto URL.
 */
/* #define LYNXCGI_LINKS */

#if defined(EXEC_LINKS) || defined(EXEC_SCRIPTS)

/**********
 * if ALLOW_USERS_TO_CHANGE_EXEC_WITHIN_OPTIONS 
 * is defined then the user will be able to change
 * the execution status within the options screen.
 */
/* #define ALLOW_USERS_TO_CHANGE_EXEC_WITHIN_OPTIONS */

/**********
 * if NEVER_ALLOW_REMOTE_EXEC is defined then local execution of
 * scripts or lynxexec and lynxprog URL's will only be implemented
 * from HTML files that were accessed via a "file://localhost/" URL,
 * and the options menu for "L)ocal executions links" will only
 * allow toggling between "ALWAYS OFF" and "FOR LOCAL FILES ONLY".
 */
/* #define NEVER_ALLOW_REMOTE_EXEC */

/*****************************
 * These are for executable shell scripts and links.
 * Set to FALSE unless you really know what you're
 * doing.
 *
 * This only applies if you are compiling with EXEC_LINKS or
 * EXEC_SCRIPTS defined.
 *
 * The first two settings:
 * LOCAL_EXECUTION_LINKS_ALWAYS_ON 
 * LOCAL_EXECUTION_LINKS_ON_BUT_NOT_REMOTE
 * specify the DEFAULT setting of the users execution link
 * options, but the user may still change those options.
 * If you do not wish the user to be able to change the
 * execution link settings you may wish to use the commandline option:
 *    -restrictions=exec_frozen
 *
 * LOCAL_EXECUTION_LINKS_ALWAYS_ON will be FALSE
 * if NEVER_ALLOW_REMOTE_EXEC has been defined.
 *
 * if LOCAL_EXECUTION_LINKS_ALWAYS_OFF_FOR_ANONYMOUS is 
 * true all execution links will be disabled when the
 * -anonymous command line option is used.  Anonymous
 * users are not allowed to change the execution options
 * from within the Lynx options menu so you might be able
 * to use this option to enable execution links and set
 * LOCAL_EXECUTION_LINKS_ON_BUT_NOT_REMOTE to TRUE to
 * give anonymous execution link capability without compromising
 * your system (see comments about TRUSTED_EXEC rules in
 * lynx.cfg for more information).
 *
 */
#define LOCAL_EXECUTION_LINKS_ALWAYS_ON          FALSE
#define LOCAL_EXECUTION_LINKS_ON_BUT_NOT_REMOTE  FALSE
#define LOCAL_EXECUTION_LINKS_ALWAYS_OFF_FOR_ANONYMOUS FALSE

#endif /*  defined(EXEC_LINKS) || defined(EXEC_SCRIPTS) */

/*********************************
 *  MAIL_SYSTEM_ERROR_LOGGING will send a message to the owner of 
 *  the information if there is one, every time
 *  that a document cannot be accessed!
 *
 *  NOTE: This can generate A LOT of mail, be warned.
 */
#define MAIL_SYSTEM_ERROR_LOGGING   FALSE  /*mail a message for every error?*/

/*********************************
 * If CHECKMAIL is set to TRUE, the user will be informed (via a statusline
 * message) about the existence of any unread mail at startup of Lynx, and
 * will get statusline messages if subsequent new mail arrives.  If a jumps
 * file with a lynxprog URL for invoking mail is available, or your html
 * pages include an mail launch file URL, the user thereby can access mail
 * and read the messages.  The checks and statusline reports will not be
 * performed if Lynx has been invoked with the -restrictions=mail switch.
 *
 *  VMS USERS !!!
 * New mail is normally broadcast as it arrives, via "unsolicitied screen
 * broadcasts", which can be "wiped" from the Lynx display via the Ctrl-W
 * command.  You may prefer to disable the broadcasts and use CHECKMAIL
 * instead (e.g., in a public account which will be used by people who
 * are ignorant about VMS).
 */
#define CHECKMAIL	FALSE	/* report unread and new mail messages */

/*********************************
 * VI_KEYS can be turned on by the user in the options
 * screen or the .lynxrc file.  This is just the default.
 */
#define VI_KEYS_ALWAYS_ON           FALSE /* familiar h,j,k, & l */

/*********************************
 * EMACS_KEYS can be turned on by the user in the options
 * screen or the .lynxrc file.  This is just the default.
 */
#define EMACS_KEYS_ALWAYS_ON           FALSE /* familiar ^N, ^P, ^F, ^B */

/*********************************
 * DEFAULT_KEYPAD_MODE specifies whether by default the user
 * has numbers that work like arrows or else numbered links
 * DEFAULT KEYPAD MODE may be set to 
 *	LINKS_ARE_NUMBERED  or
 *	NUMBERS_AS_ARROWS
 */
#define DEFAULT_KEYPAD_MODE	       NUMBERS_AS_ARROWS

/********************************
 * The default search.
 * This is a default that can be overridden by the user!
 */
#define CASE_SENSITIVE_ALWAYS_ON    FALSE /* case sensitive user search */

/********************************
 * If NO_DOT_FILES is set TRUE here or in lynx.cfg, the user will not be
 * allowed to specify files beginning with a dot in reply to output filename
 * prompts, and files beginning with a dot (e.g., file://localhost/foo/.lynxrc)
 * will not be included in the directory browser's listings.  The setting here
 * will be overridden by the setting in lynx.cfg.  If FALSE, you can force it
 * to be treated as TRUE via -restrictions=dotfiles (or -anonymous, which sets
 * this and most other restrictions).
 *
 * If it's FALSE at startup of Lynx, the user can regulate it via the
 * 'o'ptions menu, and may save the preference in the RC file.
 */
#define NO_DOT_FILES    TRUE  /* disallow access to dot files */

/********************************
 * If MAKE_LINKS_FOR_ALL_IMAGES is TRUE, all images will be given links
 * which can be ACTIVATEd.  For inlines, the ALT or pseudo-ALT ("[INLINE]")
 * strings will be links for the resolved SRC rather than just text.  For
 * ISMAP or other graphic links, the ALT or pseudo-ALT ("[ISMAP]" or "[LINK]")
 * strings will have '-' and a link labeled "[IMAGE]" for the resolved SRC
 * appended.
 *
 * The default defined here can be changed in lynx.cfg, and the user can
 * use LYK_IMAGE_TOGGLE to toggle the feature on or off at run time.
 *
 * The default also can be toggled via an "-image_links" command line switch.
 */
#define MAKE_LINKS_FOR_ALL_IMAGES	FALSE /* inlines cast to links */

/********************************
 * If MAKE_PSEUDO_ALTS_FOR_INLINES is FALSE, inline images which do not
 * specify an ALT string will not have "[INLINE]" inserted as a pseudo-ALT,
 * i.e., they'll be treated as having ALT="".  If MAKE_LINKS_FOR_ALL_IMAGES
 * is defined or toggled to TRUE, however, the pseudo-ALTs will be created
 * for inlines, so that they can be used as links to the SRCs.
 *
 * The default defined here can be changed in lynx.cfg, and the user can
 * use LYK_INLINE_TOGGLE to toggle the feature on or off at run time.
 *
 * The default also can be toggled via a "-pseudo_inlines" command line
 * switch.
 */
#define MAKE_PSEUDO_ALTS_FOR_INLINES	TRUE /* Use "[INLINE]" pseudo-ALTs */

/********************************
 * If SUBSTITUTE_UNDERSCORES is FALSE, the _underline_ format will not be
 * used in dumps.
 *
 * The default defined here can be changed in lynx.cfg, and the user can
 * toggle the default via a "-underscore" command line switch.
 */
#define SUBSTITUTE_UNDERSCORES	TRUE /* Use _underline_ format in dumps */

/********************************
 * If QUIT_DEFAULT_YES is defined then when the QUIT command is entered,
 * any response other than n or N will confirm.  Comment this out if
 * you prefer the more conservative action of requiring an explicit
 * Y or y to confirm.
 */
#define QUIT_DEFAULT_YES

/********************************
 * These definitions specify files created or used in conjunction
 * with traversals.  See CRAWL.ANNOUNCE for more infomation.
 */
#define TRAVERSE_FILE "traverse.dat"
#define TRAVERSE_FOUND_FILE "traverse2.dat"
#define TRAVERSE_REJECT_FILE "reject.dat"
#define TRAVERSE_ERRORS "traverse.errors"


/****************************************************************
 *   Section 3.   Things that you should not change until you
 *  		  have a good knowledge of the program
 */

#define LYNX_NAME "Lynx"
#define LYNX_VERSION "2.5FM (developmental version of 07-12-96)"
#ifndef MAXINT
#define MAXINT 2147483647
#endif /* !MAXINT */

/* text strings for certain actions */
/* changing these text strings is a way to customize 
 * your environment to better suit your tastes
 */
#ifdef QUIT_DEFAULT_YES
#define REALLY_QUIT "Are you sure you want to quit? [Y] "
#ifdef VMS
#define REALLY_EXIT "Really exit from Lynx? [Y] "
#endif /* VMS */
#else
#define REALLY_QUIT "Are you sure you want to quit? [N] "
#ifdef VMS
#define REALLY_EXIT "Really exit from Lynx? [N] "
#endif /* VMS */
#endif /* QUIT_DEFAULT_YES */
#define CANCELLED "Cancelled!!!"
#define CANCELLING "Cancelling!"
#define NO_CANCEL "Excellent!!!"
#define OPERATION_DONE "Done!"
#define BAD_REQUEST "Bad request!"
#define HELP \
 "Commands: Use arrow keys to move, '?' for help, 'q' to quit, '<-' to go back."
#define MOREHELP \
 "-- press space for more, use arrow keys to move, '?' for help, 'q' to quit."
#define MORE "-- press space for next page --"
#define FORM_LINK_TEXT_MESSAGE \
 "(Text entry field) Enter text.  Use UP or DOWN arrows or tab to move off."
#define FORM_LINK_TEXT_UNM_MSG \
 "UNMODIFIABLE form text field.  Use UP or DOWN arrows or tab to move off."
#define FORM_LINK_TEXT_SUBMIT_MESSAGE \
 "(Form field) Enter text.  Use <return> to submit, arrows or tab to move off."
#define FORM_LINK_TEXT_SUBMIT_UNM_MSG \
 "UNMODIFIABLE form field.  Use UP or DOWN arrows or tab to move off."
#define FORM_LINK_TEXT_SUBMIT_MAILTO_MSG \
 "(mailto form field) Enter text.  Use <return> to submit, arrows to move off."
#define FORM_LINK_TEXT_SUBMIT_MAILTO_DIS_MSG \
 "(mailto form field) Mail is disallowed so you cannot submit."
#define FORM_LINK_PASSWORD_MESSAGE \
 "(Password entry field) Enter text.  Use UP or DOWN arrows or tab to move off."
#define FORM_LINK_PASSWORD_UNM_MSG \
 "UNMODIFIABLE form password.  Use UP or DOWN arrows or tab to move off."
#define FORM_LINK_CHECKBOX_MESSAGE \
 "(Checkbox Field)   Use right-arrow or <return> to toggle."
#define FORM_LINK_CHECKBOX_UNM_MSG \
 "UNMODIFIABLE form checkbox.  Use UP or DOWN arrows or tab to move off."
#define FORM_LINK_RADIO_MESSAGE \
 "(Radio Button)   Use right-arrow or <return> to toggle."
#define FORM_LINK_RADIO_UNM_MSG \
 "UNMODIFIABLE form radio button.  Use UP or DOWN arrows or tab to move off."
#define FORM_LINK_SUBMIT_MESSAGE \
 "(Form submit button) Use right-arrow or <return> to submit ('x' for no cache)."
#define FORM_LINK_RESUBMIT_MESSAGE \
 "(Form submit button) Use right-arrow or <return> to submit."
#define FORM_LINK_SUBMIT_DIS_MSG \
 "DISABLED form submit button.  Use UP or DOWN arrows or tab to move off."
#define FORM_LINK_SUBMIT_MAILTO_MSG \
 "(mailto form submit button) Use right-arrow or <return> to submit."
#define FORM_LINK_SUBMIT_MAILTO_DIS_MSG \
 "(mailto form submit button) Mail is disallowed so you cannot submit."
#define FORM_LINK_RESET_MESSAGE \
 "(Form reset button)   Use right-arrow or <return> to reset form to defaults."
#define FORM_LINK_RESET_DIS_MSG \
 "DISABLED form reset button.  Use UP or DOWN arrows or tab to move off."
#define FORM_LINK_OPTION_LIST_MESSAGE \
 "(Option list) Hit return and use arrow keys and return to select option."
#define FORM_LINK_OPTION_LIST_UNM_MSG \
 "UNMODIFIABLE option list.  Use return or arrow keys to review or leave."
#define NORMAL_LINK_MESSAGE \
 "(NORMAL LINK)   Use right-arrow or <return> to activate."
#define LINK_NOT_FOUND "The resource requested is not available at this time."
#define WWW_WAIT_MESSAGE "Getting %s"
#define ADVANCED_URL_MESSAGE "URL: %s"
#define WWW_FAIL_MESSAGE "Unable to access WWW file!!!"
#define WWW_INDEX_MESSAGE "This is a searchable index.  Use %s to search."
#define WWW_INDEX_MORE_MESSAGE \
 "--More--  This is a searchable index.  Use %s to search."
#define BAD_LINK_NUM_ENTERED "You have entered an invalid link number."
#define SOURCE_HELP \
 "Currently viewing document source.  Press '\\' to return to rendered version."
#define NOVICE_LINE_ONE \
 "  Arrow keys: Up and Down to move. Right to follow a link; Left to go back.  \n"
#define NOVICE_LINE_TWO \
 " H)elp O)ptions P)rint G)o M)ain screen Q)uit /=search [delete]=history list \n"
#define NOVICE_LINE_TWO_A \
 "  O)ther cmds  H)elp  K)eymap  G)oto  P)rint  M)ain screen  o)ptions  Q)uit  \n"
#define NOVICE_LINE_TWO_B \
 "  O)ther cmds  B)ack  E)dit  D)ownload ^R)eload ^W)ipe screen  search doc: / \n"
#define NOVICE_LINE_TWO_C \
 "  O)ther cmds  C)omment  History: <delete>  Bookmarks: V)iew, A)dd, R)emove  \n"
#define FORM_NOVICELINE_ONE \
 "            Enter text into the field by typing on the keyboard              "
#define FORM_NOVICELINE_TWO \
"    Ctrl-U to delete all text in field, [Backspace] to delete a character    "
#define SUBMITTING_FORM "Submitting form..."
#define RESETTING_FORM "Resetting form..."
#define RELOADING_FORM \
 "Reloading document.  Any form entries will be lost!"
#define BAD_FORM_MAILTO "Malformed mailto form submission!  Cancelled!"
#define FORM_MAILTO_DISALLOWED "Mail disallowed!  Cannot submit."
#define FORM_MAILTO_FAILED "Mailto form submission failed!"
#define FORM_MAILTO_CANCELLED "Mailto form submission Cancelled!!!"
#define SENDING_FORM_CONTENT "Sending form content..."
#define NO_ADDRESS_IN_MAILTO_URL "No email address is present in mailto URL!"
#define MAILTO_URL_TEMPOPEN_FAILED \
 "Unable to open temporary file for mailto URL!"
#define COMMENT_REQUEST_CANCELLED "Comment request cancelled!!!"
#define INC_ORIG_MSG_PROMPT \
 "Do you wish to include the original message? (y/n) "
#define SPAWNING_EDITOR_FOR_MAIL \
 "Spawning your selected editor to edit mail message"
#define ERROR_SPAWNING_EDITOR \
 "Error spawning editor, check your editor definition in the options menu"
#define SEND_COMMENT_PROMPT "Send this comment? (y/n) "
#define SENDING_YOUR_MSG "Sending your message..."
#define FILE_ACTIONS_DISALLOWED "file: ACTIONs are disallowed!"
#define FILE_SERVED_LINKS_DISALLOWED \
 "file: URLs via served links are disallowed!"
#define FILE_BOOKMARKS_DISALLOWED "file: URLs via bookmarks are disallowed!"
#define RETURN_TO_LYNX "Press <return> to return to Lynx."
#ifdef VMS
#define SPAWNING_MSG \
 "Spawning DCL subprocess.  Use 'logout' to return to Lynx.\n"
#else
#define SPAWNING_MSG \
 "Spawning your default shell.  Use 'exit' to return to Lynx.\n"
#endif /* VMS */
#define SPAWNING_DISABLED "Spawning is currently disabled."
#define DOWNLOAD_DISABLED "The 'd'ownload command is currently disabled."
#define NO_DOWNLOAD_INPUT "You cannot download a input field."
#define NO_DOWNLOAD_PRINT_OP "You cannot download a printing option."
#define NO_DOWNLOAD_UPLOAD_OP "You cannot download an upload option."
#define NO_DOWNLOAD_PERMIT_OP "You cannot download an permit option."
#define NO_DOWNLOAD_CHOICE "Nothing to download."
#define TRACE_ON "Trace ON!"
#define TRACE_OFF "Trace OFF!"
#define CLICKABLE_IMAGES_ON \
 "Links will be included for all images!  Reloading..."
#define CLICKABLE_IMAGES_OFF \
 "Standard image handling restored!  Reloading..."
#define PSEUDO_INLINE_ALTS_ON \
 "Pseudo_ALTs will be inserted for inlines without ALT strings!  Reloading..."
#define PSEUDO_INLINE_ALTS_OFF \
 "Inlines without an ALT string specified will be ignored!  Reloading..."
#define RAWMODE_OFF "Raw 8-bit or CJK mode toggled OFF!  Reloading..."
#define RAWMODE_ON "Raw 8-bit or CJK mode toggled ON!  Reloading..."
#define HEAD_D_L_OR_CANCEL \
 "Send HEAD request for D)ocument or L)ink, or C)ancel? (d,l,c): "
#define HEAD_D_OR_CANCEL \
 "Send HEAD request for D)ocument, or C)ancel? (d,c): "
#define DOC_NOT_HTTP_URL "Sorry, the document is not an http URL."
#define LINK_NOT_HTTP_URL "Sorry, the link is not an http URL."
#define FORM_ACTION_DISABLED "Sorry, the ACTION for this form is disabled."
#define FORM_ACTION_NOT_HTTP_URL \
 "Sorry, the ACTION for this form is not an http URL."
#define NOT_HTTP_URL_OR_ACTION "Not an http URL or form ACTION!"
#define NOT_IN_STARTING_REALM "URL is not in starting realm!"
#define NEWSPOSTING_DISABLED "News posting is disabled!"
#define DIRED_DISABLED "File management support is disabled!"
#define JUMP_DISALLOWED "Jumping to a shortcut URL is disallowed!"
#define RANDOM_URL_DISALLOWED "Random URL is disallowed!  Use a shortcut."
#define NO_RANDOM_URLS_YET "No random URLs have been used thus far."
#define BOOKMARKS_DISABLED "Bookmark features are currently disabled."
#define BOOKMARK_EXEC_DISABLED "Execution via bookmarks is disabled."
#define BOOKMARK_FILE_NOT_DEFINED \
 "Bookmark file is not defined. Use %s to see options."
#define NO_TEMP_FOR_HOTLIST \
 "Unable to open tempfile for X Mosaic hotlist conversion."
#define BOOKMARK_OPEN_FAILED "ERROR - unable to open bookmark file."
#define BOOKMARK_OPEN_FAILED_FOR_DEL \
 "Unable to open bookmark file for deletion of link."
#ifdef VMS
#define BOOKSCRA_OPEN_FAILED_FOR_DEL \
 "Unable to open scratch file for deletion of link."
#define ERROR_RENAMING_SCRA "Error renaming scratch file."
#else
#define BOOKTEMP_OPEN_FAILED_FOR_DEL \
 "Unable to open temporary file for deletion of link."
#define ERROR_RENAMING_TEMP "Error renaming temporary file."
#define BOOKTEMP_REOPEN_FAIL_FOR_DEL \
 "Unable to reopen temporary file for deletion of link."
#endif /* VMS */
#define BOOKMARK_LINK_NOT_ONE_LINE \
 "Link is not by itself all on one line in bookmark file."
#define BOOKMARK_DEL_FAILED "Bookmark deletion failed."
#define BOOKMARKS_NOT_TRAVERSED \
 "Bookmark files cannot be traversed (only http URLs)."
#define BOOKMARKS_NOT_OPEN \
 "Unable to open bookmark file, use 'a' to save a link first"
#define BOOK_D_L_OR_CANCEL \
 "Save D)ocument or L)ink to bookmark file or C)ancel? (d,l,c): "
#define BOOK_D_OR_CANCEL "Save D)ocument to bookmark file or C)ancel? (d,c): "
#define NOBOOK_FORM_FIELD "Cannot save form fields/links"
#define NOBOOK_HSML \
 "History, showinfo, menu and list files cannot be saved as bookmarks."
#define CONFIRM_BOOKMARK_DELETE \
 "Do you really want to delete this link from your bookmark file? (y/n)"
#define HISTORICAL_ON_MINIMAL_OFF \
 "Historical comment parsing ON (Minimal is overridden)!"
#define HISTORICAL_OFF_MINIMAL_ON \
 "Historical comment parsing OFF (Minimal is in effect)!"
#define HISTORICAL_ON_VALID_OFF \
 "Historical comment parsing ON (Valid is overridden)!"
#define HISTORICAL_OFF_VALID_ON \
 "Historical comment parsing OFF (Valid is in effect)!"
#define MINIMAL_ON_IN_EFFECT \
 "Minimal comment parsing ON (and in effect)!"
#define MINIMAL_OFF_VALID_ON \
 "Minimal comment parsing OFF (Valid is in effect)!"
#define MINIMAL_ON_BUT_HISTORICAL \
 "Minimal comment parsing ON (but Historical is in effect)!"
#define MINIMAL_OFF_HISTORICAL_ON \
 "Minimal comment parsing OFF (Historical is in effect)!"
#define SOFT_DOUBLE_QUOTE_ON "Soft double-quote parsing ON!"
#define SOFT_DOUBLE_QUOTE_OFF "Soft double-quote parsing OFF!"
#define ALREADY_AT_END "You are already at the end of this document."
#define ALREADY_AT_BEGIN "You are already at the beginning of this document."
#define ALREADY_AT_FIRST "You are already at the first document"
#define NO_LINKS_ABOVE "There are no links above this line of the document."
#define NO_LINKS_BELOW "There are no links below this line of the document."
#define MAXLEN_REACHED_DEL_OR_MOV \
 "Maximum length reached!  Delete text or move off field."
#define NOT_ON_SUBMIT_OR_LINK \
 "You are not on a form submission button or normal link."
#define NEED_CHECKED_RADIO_BUTTON \
 "One radio button must be checked at all times!"
#define PREV_DOC_QUERY "Do you want to go back to the previous document? [N]"
#define ARROWS_OR_TAB_TO_MOVE "Use arrows or tab to move off of field."
#define ENTER_TEXT_ARROWS_OR_TAB \
 "Enter text. Use arrows or tab to move off of field."
#define NO_FORM_ACTION "** Bad HTML!!  No form action defined. **"
#define BAD_HTML_NO_POPUP "Bad HTML!!  Unable to create popup window!"
#define POPUP_FAILED "Unable to create popup window!"
#define GOTO_DISALLOWED "Goto a random URL is disallowed!"
#define URL_TO_OPEN "URL to open: "
#define EDIT_CURRENT_GOTO "Edit the current Goto URL: "
#define EDIT_THE_PREV_GOTO "Edit the previous Goto URL: "
#define EDIT_A_PREV_GOTO "Edit a previous Goto URL: "
#define ENTER_DATABASE_QUERY "Enter a database query: "
#define ENTER_WHEREIS_QUERY "Enter a whereis query: "
#define EDIT_CURRENT_QUERY "Edit the current query: "
#define EDIT_THE_PREV_QUERY "Edit the previous query: "
#define EDIT_A_PREV_QUERY "Edit a previous query: "
#define USE_C_R_TO_RESUB_CUR_QUERY \
 "Use Control-R to resubmit the current query."
#define EDIT_CURRENT_SHORTCUT "Edit the current shortcut: "
#define EDIT_THE_PREV_SHORTCUT "Edit the previous shortcut: "
#define EDIT_A_PREV_SHORTCUT "Edit a previous shortcut: "
#define KEY_NOT_MAPPED_TO_JUMP_FILE "Key '%c' is not mapped to a jump file!"
#define CANNOT_LOCATE_JUMP_FILE "Cannot locate jump file!"
#define CANNOT_OPEN_JUMP_FILE "Cannot open jump file!"
#define ERROR_READING_JUMP_FILE "Error reading jump file!"
#define OUTOF_MEM_FOR_JUMP_FILE "Out of memory reading jump file!"
#define OUTOF_MEM_FOR_JUMP_TABLE "Out of memory reading jump table!"
#define GOTO_FILE_DISALLOWED "You are not allowed to goto \"file:\" URL's"
#define GOTO_EXEC_DISALLOWED "You are not allowed to goto \"lynxexec:\" URL's"
#define GOTO_PROG_DISALLOWED "You are not allowed to goto \"lynxprog:\" URL's"
#define GOTO_CGI_DISALLOWED "You are not allowed to goto \"lynxcgi:\" URL's"
#define GOTO_NON_HTTP_DISALLOWED "Goto a non-http URL is disallowed!"
#define NO_INDEX_FILE "No index is currently available."
#define CONFIRM_MAIN_SCREEN \
 "Do you really want to go to the Main screen? (y/n) [n] "
#define IN_MAIN_SCREEN "You are already at main screen!"
#define NOT_ISINDEX \
 "Not a searchable indexed document -- press '/' to search for a text string"
#define NO_OWNER \
 "No owner is defined for this file so you cannot send a comment"
#define CONFIRM_COMMENT "Do you wish to send a comment? [N]"
#define MAIL_DISALLOWED "Mail is disallowed so you cannot send a comment"
#define EDIT_DISABLED "The 'e'dit command is currently disabled."
#define NO_STATUS "System error - failure to get status."
#define NO_EDITOR "No editor is defined!"
#define PRINT_DISABLED "The 'p'rint command is currently disabled."
#define NO_TOOLBAR "Document has no Toolbar links or Banner."
#define NOOPEN_TRAV_ERR_FILE "Unable to open traversal errors output file"
#define FOLLOW_LINK_NUMBER "Follow link number: "
#define BAD_HTML_USE_TRACE "** Bad HTML!!  Use -trace to diagnose. **"
#define CANNOT_OPEN_TEMP "Can't open temporary file!"
#define CANNOT_OPEN_OUTPUT "Can't open output file!  Cancelling!"
#define EXECUTION_DISABLED "Execution is disabled."
#define EXECUTION_DISABLED_FOR_FILE \
 "Execution is not enabled for this file. See the Options menu (use %s)."
#define EXECUTION_NOT_COMPILED \
 "Execution capabilities are not compiled into this version."
#define CANNOT_DISPLAY_FILE "This file cannot be displayed on this terminal."
#define CANNOT_DISPLAY_FILE_D_OR_C \
 "This file cannot be displayed on this terminal:  D)ownload, or C)ancel"
#define WRONG_CHARSET_D_OR_C "%s  D)ownload, or C)ancel"
#define CANCELLING_FILE "Cancelling file."
#define RETRIEVING_FILE "Retrieving file.  - PLEASE WAIT -"
#define FILENAME_PROMPT "Enter a filename: "
#define EDIT_THE_PREV_FILENAME "Edit the previous filename: "
#define EDIT_A_PREV_FILENAME "Edit a previous filename: "
#define NEW_FILENAME_PROMPT "Enter a new filename: "
#define FILENAME_CANNOT_BE_DOT "File name may not begin with a dot."
#ifdef VMS
#define FILE_EXISTS_HPROMPT "File exists. Create higher version? (y/n)"
#else
#define FILE_EXISTS_OPROMPT "File exists. Overwrite? (y/n)"
#endif /* VMS */
#define CANNOT_WRITE_TO_FILE "Cannot write to file."
#define MISCONF_DOWNLOAD_COMMAND "ERROR! - download command is misconfigured."
#define CANNOT_DOWNLOAD_FILE "Unable to download file."
#define SAVING "Saving..."
#define COULD_NOT_ACCESS_FILE "Could not access file."
#define CANNOT_EDIT_REMOTE_FILES \
 "Lynx cannot currently (E)dit remote WWW files"
#define NOAUTH_TO_EDIT_FILE "You are not authorized to edit this file."
#define TITLE_PROMPT "Title: "
#define SUBJECT_PROMPT "Subject: "
#define USERNAME_PROMPT "Username: "
#define PASSWORD_PROMPT "Password: "
#define USERNAME_PASSWORD_REQUIRED "lynx: Username and Password required!!!"
#define PASSWORD_REQUIRED "lynx: Password required!!!"
#define CGI_DISABLED "cgi support has been disabled by system administrator."
#define CGI_NOT_COMPILED \
 "Lynxcgi capabilities are not compiled into this version."
#define CANNOT_CONVERT_I_TO_O "Sorry, no known way of converting %s to %s."
#define CONNECT_SET_FAILED "Unable to set up connection."
#define CONNECT_FAILED "Unable to make connection"
#define MALFORMED_EXEC_REQUEST \
 "Executable link rejected due to malformed request."
#define BADCHAR_IN_EXEC_LINK \
 "Executable link rejected due to `%c' character."
#define BADLOCPATH_IN_EXEC_LINK \
 "Executable link rejected due to location or path."
#define MAIL_DISABLED "Mail access is disabled!"
#define ACCESS_ONLY_LOCALHOST \
 "Only files and servers on the local host can be accessed."
#define TELNET_DISABLED "Telnet access is disabled!"
#define TELNET_PORT_SPECS_DISABLED \
 "Telnet port specifications are disabled."
#define NEWS_DISABLED "USENET news access is disabled!"
#define RLOGIN_DISABLED "Rlogin access is disabled!"
#define FTP_DISABLED "Ftp access is disabled!"
#define NO_REFS_FROM_DOC "There are no references from this document."
#ifdef VMS
#define CANNOT_OPEN_COMFILE "Unable to open command file."
#endif /* VMS */
#define NEWS_POST_CANCELLED "News Post Cancelled!!!"
#define SPAWNING_EDITOR_FOR_NEWS \
 "Spawning your selected editor to edit news message"
#define POST_MSG_PROMPT "Post this message? (y/n) "
#ifdef VMS
#define HAVE_UNREAD_MAIL_MSG "*** You have unread mail. ***"
#else
#define HAVE_MAIL_MSG "*** You have mail. ***"
#endif /* VMS */
#define HAVE_NEW_MAIL_MSG "*** You have new mail. ***"
#define SAVE_REQUEST_CANCELLED "Save request cancelled!!!"
#define MAIL_REQUEST_CANCELLED "Mail request cancelled!!!"
#define MAILING_FILE "Mailing file.  Please wait..."
#define MAIL_REQUEST_FAILED "ERROR - Unable to mail file"
#define CONFIRM_LONG_SCREEN_PRINT \
 "File is %d screens long.  Are you sure you want to print? [y]"
#define PRINT_REQUEST_CANCELLED "Print request cancelled!!!"
#define PRESS_RETURN_TO_BEGIN "Press <return> to begin: "
#define PRESS_RETURN_TO_FINISH "Press <return> to finish: "
#define CONFIRM_LONG_PAGE_PRINT \
 "File is %d pages long.  Are you sure you want to print? [y]"
#define FILE_ALLOC_FAILED "ERROR - Unable to allocate file space!!!"
#define UNABLE_TO_OPEN_TEMPFILE "Unable to open tempfile"
#define UNABLE_TO_OPEN_PRINTOP_FILE "Unable to open print options file"
#define PRINTING_FILE "Printing file.  Please wait..."
#define MAIL_ADDRESS_PROMPT "Please enter a valid internet mail address: "
#define PRINTER_MISCONF_ERROR "ERROR! - printer is misconfigured!"
#define MISDIRECTED_MAP_REQUEST "Misdirected client-side image MAP request!"
#define MAP_NOT_ACCESSIBLE "Client-side image MAP is not accessible!"
#define MAPS_NOT_AVAILABLE "No client-side image MAPs are available!"
#define MAP_NOT_AVAILABLE "Client-side image MAP is not available!"
#define OPTION_SCREEN_NEEDS_24 \
 "Screen height must be at least 24 lines for the Options menu!"
#define OPTION_SCREEN_NEEDS_23 \
 "Screen height must be at least 23 lines for the Options menu!"
#define OPTION_SCREEN_NEEDS_22 \
 "Screen height must be at least 22 lines for the Options menu!"
#define COMMAND_PROMPT "Command: "
#define SELECT_SEGMENT "Select "
#define CAP_LETT_SEGMENT "capital letter"
#define OF_OPT_LINE_SEGMENT " of option line,"
#define TO_SAVE_SEGMENT " to save,"
#define OR_SEGMENT " or "
#define TO_RETURN_SEGMENT " to return to Lynx."
#define ACCEPT_DATA "Hit return to accept entered data."
#define VALUE_ACCEPTED "Value accepted!"
#define VALUE_ACCEPTED_WARNING_X \
 "Value accepted! -- WARNING: Lynx is configured for XWINDOWS!"
#define VALUE_ACCEPTED_WARNING_NONX \
 "Value accepted! -- WARNING: Lynx is NOT configured for XWINDOWS!"
#define EDITOR_LOCKED "You are not allowed to change which editor to use!"
#define FAILED_TO_SET_DISPLAY "Failed to set DISPLAY variable!"
#define FAILED_CLEAR_SET_DISPLAY "Failed to clear DISPLAY variable!"
#define BOOKMARK_CHANGE_DISALLOWED \
 "You are not allowed to change the bookmark file!"
#define DOTFILE_ACCESS_DISABLED "Access to dot files is disabled!"
#define UA_COPYRIGHT_WARNING \
 "WARNING: Misrepresentaton of the User-Agent may be a copyright violation!"
#define CHANGE_OF_SETTING_DISALLOWED \
 "You are not allowed to change this setting."
#define SAVING_OPTIONS "Saving Options..."
#define OPTIONS_SAVED "Options saved!"
#define OPTIONS_NOT_SAVED "Unable to save Options!"
#define R_TO_RETURN_TO_LYNX " 'r' to return to Lynx "
#define SAVE_OR_R_TO_RETURN_TO_LYNX " '>' to save, or 'r' to return to Lynx "
#define ANY_KEY_CHANGE_RET_ACCEPT \
 "Hit any key to change value; RETURN to accept: "
#define ERROR_UNCOMPRESSING_TEMP "Error uncompressing temporary file!"

#ifdef DIRED_SUPPORT
#define DIRED_NOVICELINE \
 "  C)reate  D)ownload  E)dit  F)ull menu  M)odify  R)emove  T)ag  U)pload     \n"
#define CURRENT_LINK_STATUS_FAILED "Failed to obtain status of current link!"
#endif /* DIRED_SUPPORT */

#define MAXBASE 100       /* max length of base directory */
#define MAXHIGHLIGHT 160 /* max length of highlighted text */
#define MAXTARGET 130    /* max length of target string */
#define LINESIZE 1024    /* max length of line to read from file*/
#define MAXFNAME 1280	/* max filename length DDD/FILENAME.EXT */
#define MAXCOMMAND MAXFNAME /* max length of command should be the same */
#define MAXHIST  512	/* number of links we remember in history */
#define MAXLINKS 256	/* max links on one screen */

#ifdef VMS
/* Use the VMS port of gzip for uncompressing both .Z and .gz files. */
#define UNCOMPRESS_PATH  "gzip -d"
#define GZIP_PATH "gzip"
#else
/* Check these paths on Unix. */
#define	COMPRESS_PATH	"/usr/bin/compress"
#define	UNCOMPRESS_PATH	"/usr/bin/uncompress"
#define UUDECODE_PATH   "/usr/bin/uudecode"
#define	ZCAT_PATH	"/usr/bin/zcat"
#define	GZIP_PATH	"/local/bin/gzip"
#define	ZIP_PATH	"/local/bin/zip"
#define	UNZIP_PATH	"/local/bin/unzip"
#define	INSTALL_PATH	"/etc/install"
#define	MKDIR_PATH	"/bin/mkdir"
#define	MV_PATH		"/bin/mv"
#define	RM_PATH		"/bin/rm"
#define	TAR_PATH	"/usr/bin/tar"
#define	TOUCH_PATH	"/bin/touch"
#define COPY_PATH	"/bin/cp"
#define CHMOD_PATH	"/bin/chmod"
#endif /* VMS */

#endif /* USERDEFS_H */
